@@ -23,9 +23,10 @@ import re
 import sys
 from calculate.lib.utils.colortext.palette import TextState
 from calculate.lib.utils.tools import ignore
+from calculate.lib.utils.git import Git, GitError
 from calculate.lib.utils.portage import (EmergePackage, PackageList,
                                          EmergeUpdateInfo,
-                                         EmergeRemoveInfo, Git, GitError)
+                                         EmergeRemoveInfo)
 
 Colors = TextState.Colors
 import pexpect
