@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2014 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2014-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,12 +13,12 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
 import sys
 from os import path
 import shutil
-import os
-from calculate.lib.utils.files import listDirectory, readFile, readLinesFile, \
-    makeDirectory, removeDir
+from calculate.lib.utils.files import (listDirectory, readFile, readLinesFile,
+                                       makeDirectory, removeDir)
 from calculate.lib.utils.git import Git
 from update import UpdateError
 
@@ -27,8 +27,17 @@ setLocalTranslate('cl_update3', sys.modules[__name__])
 
 DEFAULT_BRANCH = Git.Reference.Master
 
+class RepositoryStorageInterface(object):
+    def __iter__(self):
+        raise StopIteration
 
-class RepositoryStorage(object):
+    def get_profiles(self, url, branch=DEFAULT_BRANCH):
+        return []
+
+    def get_repository(self, url, branch=DEFAULT_BRANCH):
+        return None
+
+class RepositoryStorage(RepositoryStorageInterface):
     directory = '/tmp'
 
     def __init__(self, directory):
@@ -44,6 +53,10 @@ class RepositoryStorage(object):
     def get_profiles(self, url, branch=DEFAULT_BRANCH):
         return []
 
+    def get_repository(self, url, branch=DEFAULT_BRANCH):
+        return None
+
+
 class ProfileStorage(RepositoryStorage):
     def get_profiles(self, url, branch=DEFAULT_BRANCH):
         rep = self.get_repository(url, branch)
@@ -54,6 +67,7 @@ class ProfileStorage(RepositoryStorage):
     def get_repository(self, url, branch=DEFAULT_BRANCH):
         return None
 
+
 class LocalStorage(ProfileStorage):
     """
     Локальное хранилище репозиториев, при запросе по урлу смотрит, доступные
@@ -64,7 +78,6 @@ class LocalStorage(ProfileStorage):
             if rep.is_like(url, branch):
                 return rep
 
-
 class CacheStorage(ProfileStorage):
     """
     Хранилище репозиториев, при запросе по урлу смотрит, доступные
@@ -78,7 +91,7 @@ class CacheStorage(ProfileStorage):
         else:
             return ProfileRepository.clone(url, self, branch)
 
-class RepositoryStorageSet(RepositoryStorage):
+class RepositoryStorageSet(RepositoryStorageInterface):
     """
     Набор хранилищ репозиториев
     """
