@@ -254,7 +254,8 @@ class ClUpdateAction(Action):
                                Get('cl_update_metadata_force') == 'force'))
              },
              {'name': 'eix_update',
-              'message': __("Updating the eix cache for {cl_repository_name}"),
+              'message': __("Updating the eix cache for "
+                            "{cl_update_eix_repositories}"),
               'method': 'Update.eixUpdate(cl_repository_name)',
               'condition': (
                   lambda Get: (Get('cl_update_outdate_set') == 'on' and
