@@ -39,6 +39,7 @@ from ..profile import (RepositoryStorageSet, DEFAULT_BRANCH,
 from calculate.lib.variables import linux as lib_linux
 from calculate.lib.variables import env
 from calculate.update.update_info import UpdateInfo
+from itertools import chain
 import time
 
 _ = lambda x: x
@@ -1561,3 +1562,14 @@ class VariableClUpdateOnedepthSet(Variable):
     def init(self):
         self.label = _("Clear the history of repositories")
         self.help = _("clear the history of repositories")
+
+
+class VariableClUpdateEixRepositories(ReadonlyVariable):
+    """
+    Отображаемый список обновляемых репозиториев eix
+    """
+    def get(self):
+        return ", ".join(
+            x for x in chain(
+                reversed(self.Get('update.cl_update_rep_name')),
+                self.Get('update.cl_update_other_rep_name')))
